@charset "utf-8";
/* CSS Document */

body{
	font-family:Arno Pro Light Display;
	font-size:15px;
}

h1{
	font-family:Trajan Pro Bold;
	color:rgba(186,152,104,1.00);
	font-size:24px;
	
}

h2{
	color:rgba(186,152,104,1.00);
	font-size:15px;
	
}

a{
	color:rgba(42,128,119,1.00);

}

a:hover {
	color:#000;
	text-decoration:none
}

ul{
	list-style-type:none;
}

ul, li{
	padding-left:5px;
	line-height:30px;	
	
}

.left-list{
	border-right: 1px solid rgba(42,128,119,0.50);
	padding-left: 22%;
	padding-right: 10px;
	padding-top: 10px;
	padding-bottom: 10px;
	height:100vh;

}

.left-list-home{
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 10px;
	padding-bottom: 10px;
}

.shop-setting-section{
	float: right;
	width: 30%;
	clear: right;
}
.shop-setting-wrapper{

	float:right;
}	

.page-bar{
	padding-top: 10px;
}

.animate-show{
	
	padding-left: 10px;
	padding-right: 5%;
	padding-top: 0px;
	padding-bottom: 10px;
}

/*.product-img{
	padding-left: 30px;
	padding-right: 30px;
	padding-top: 30px;
	padding-bottom: 30px;

}*/

.product-li-img{
	padding-left: 30px;
	padding-right: 30px;
	padding-top: 30px;
	padding-bottom: 30px;
}

.product-li-text{
	font-size: 16px;
	text-align: center;
	padding-top: 10px;
	line-height:12px;
	
}

.top-bar{
	border-bottom: 1px solid rgba(42,128,119,0.50);
	padding-left:6.5%;
	padding-right:6.5%;
	padding-top:10px;

}

.fixed-menu-container{
	top:10px;
	right: 4px;
	z-index: 999;
	float:right;

}

.btn{
	border:1px solid rgba(42,128,119,0.50);
	padding:5px 8px;
	width:auto;
	height:auto;
	background-color:#FFFFFF;
	color:1px solid rgba(42,128,119,1);
	font-weight:700px;
	font-size:13px;
	opacity:0.8;
	margin-left:4px;
	float:right;
}

.top-menu-bar{}

	
.header{
	}
	
.our-product{
	margin-bottom: 2px;
	bottom:0px;
	right:0px;
}	
	
.our-product-text{
	text-align: center;
	font-size: 36px;
	font-weight: lighter;
	font-family: Times New Roman;
	font-style: italic;
	color:rgba(90,179,171,1.00);
	padding-top:0px;
	}
	
	
	/* img mouse over effect */
	
.hovereffect {
  width: 100%;
  height: 100%;

  overflow: hidden;
  position: relative;
  text-align: center;
  cursor: default;
}

.hovereffect .overlay {
  position: absolute;
  overflow: hidden;
  width: 80%;
  height: 80%;
  left: 10%;
  top: 10%;
  border-bottom: 1px solid rgba(42,128,119,1);
  border-top: 1px solid rgba(42,128,119,1);
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: scale(0,1);
  -ms-transform: scale(0,1);
  transform: scale(0,1);
}


.hovereffect:hover .overlay {
  opacity: 1;
  filter: alpha(opacity=100);
  -webkit-transform: scale(1);
  -ms-transform: scale(1);
  transform: scale(1);
}

.hovereffect img {
  display: block;
  position: relative;
  -webkit-transition: all 0.35s;
  transition: all 0.35s;
}

.hovereffect:hover img {
  filter: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg"><filter id="filter"><feComponentTransfer color-interpolation-filters="sRGB"><feFuncR type="linear" slope="0.6" /><feFuncG type="linear" slope="0.6" /><feFuncB type="linear" slope="0.6" /></feComponentTransfer></filter></svg>#filter');
  filter: opacity(0.2);
  -webkit-filter: opacity(0.2);
}

.hovereffect h2 {
  text-transform: uppercase;
  text-align: center;
  position: relative;
  font-size: 17px;
  background-color: transparent;
  color:  rgba(42,128,119,1);
  padding: 1em 0;
  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,-100%,0);
  transform: translate3d(0,-100%,0);
}

.hovereffect a, hovereffect p {
  color:  rgba(42,128,119,1);
  padding: 1em 0;
  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,100%,0);
  transform: translate3d(0,100%,0);
}

.hovereffect:hover a, .hovereffect:hover p, .hovereffect:hover h2 {
  opacity: 1;
  filter: alpha(opacity=100);
  -webkit-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
}

.img-responsive{
	padding-bottom:10px;
	
	}
	/* img mouse over effect */


.product-img li{
	float:left;
}

@media (min-width: 200px) {
	.info-input-group {
  position: relative;
  display: table;
  border-collapse: separate;
  width:100%;
  }
	
  .container {
    width: 320px;
  }
  .product-li-img{
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 10px;
	padding-bottom: 10px;

}
.our-product{
	margin-bottom: 2px;
	bottom:0px;
	right:0px;
}

.fixed-menu-container{
	padding-left: 0px;
	padding-right: 0px;
	}
	
.addtothecart{
	width:100%
}

.title{
	color:rgba(186,152,104,1.00);
	font-size:25px;
}
.fp-section.fp-table, .fp-slide.fp-table {
    display: table;
    table-layout:fixed;
    width: 100%;
	background:#FFF;
}

}
@media (min-width: 768px) {
	.fp-section.fp-table, .fp-slide.fp-table {
    display: table;
    table-layout:fixed;
    width: 100%;
	background:0;

}
	
	.Contact-text{
	padding:0 0;
	font-style: italic;

	}

	.about-text{
	padding:0 0;
	font-style: italic;
	}
	
	.info-input-group {
  position: relative;
  display: table;
  border-collapse: separate;
  width:80%;
  }
	
  .container {
    width: 750px;
  }
  .product-li-img{
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 10px;
	padding-bottom: 10px;
}

.our-product{
	margin-bottom: 2px;
	bottom:0px;
	right:0px;
}

	.addtothecart{
	width:80%
}

.title{
	color:rgba(186,152,104,1.00);
	font-size:36px;
}

}
@media (min-width: 990px) and (max-width: 1799px) {
	.Contact-text{
	padding-right:40%;
	font-style: italic;

	}

	.about-text{
	padding-left:40%;
	font-style: italic;
	}
.info-input-group {
  position: relative;
  display: table;
  border-collapse: separate;
  width:50%;
  }
	
  .container {
    width: 100%;
  }
  .product-li-img{
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 20px;
	padding-bottom: 20px;
}
p{
	font-size:12px;
}
ul{
	font-size:13px;
}

li{
	font-size:16px;
}
h1{
	font-size:28px;
}
.hovereffect h2 {
  text-transform: uppercase;
  text-align: center;
  position: relative;
  font-size: 6px;
  background-color: transparent;
  color:  rgba(42,128,119,1);
  padding: 0px 0;
  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,-100%,0);
  transform: translate3d(0,-100%,0);
}

.our-product{
	margin-bottom: 2px;
	position:absolute;
	bottom:0px;
	right:0px;
}
	.{
		width:50%
	}
	.addtothecart{
	width:50%
}

.our-product-text{
	text-align: center;
	font-size: 25px;
	font-weight: lighter;
	font-family: Times New Roman;
	font-style: italic;
	color:rgba(90,179,171,1.00);
	padding-top:0px;
	}
	
	.title{
	color:rgba(186,152,104,1.00);
	font-size:36px;
}

}
@media (min-width: 1800px) {
		.Contact-text{
	padding-right:40%;
	font-style: italic;

	}

	.about-text{
	padding-left:40%;
	font-style: italic;
	}

.info-input-group {
  position: relative;
  display: table;
  border-collapse: separate;
  width:50%;
  }

	
  .container {
	width: 1920px;
  }
  
  .product-li-img{
	padding-left: 30px;
	padding-right: 30px;
	padding-top: 30px;
	padding-bottom: 30px;

}
h1{
	font-family:Trajan Pro Bold;
	color:rgba(186,152,104,1.00);
	font-size:36px;
	
}

h2{
	color:rgba(186,152,104,1.00);
	font-size:17px;
	
}
P{
	font-size:15px;
	
}
li{
	font-size:18px;
	}
.hovereffect h2 {
  text-transform: uppercase;
  text-align: center;
  position: relative;
  font-size: 17px;
  background-color: transparent;
  color:  rgba(42,128,119,1);
  padding: 1em 0;
  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,-100%,0);
  transform: translate3d(0,-100%,0);
	}
	
	.our-product{
	margin-bottom: 2px;
	position:absolute;
	bottom:0px;
	right:0px;
}
	
	.our-product-text{
	text-align: center;
	font-size: 36px;
	font-weight: lighter;
	font-family: Times New Roman;
	font-style: italic;
	color:rgba(90,179,171,1.00);
	padding-top:0px;
	}
	
.{
	width:50%
}
.addtothecart{
	width:50%
}

.title{
	color:rgba(186,152,104,1.00);
	font-size:36px;
}
	
}


form{
	margin:0 auto;
}
.search { 
	padding:1px 2px 1px 3px;
	margin:1px;
	border-color: rgba(42,128,119,1.00);
}

input[type=text]{
	color:#bcbcbc;
	width:100%;
}

input[type=button], input[type=button]:hover {
	position:relative; 
	left:-6px;
	border:1px solid #adc5cf;
	background: #e4f1f9; /* Old browsers */
	background: -moz-linear-gradient(top, #e4f1f9 0%, #d5e7f3 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#e4f1f9), color-stop(100%,#d5e7f3)); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top, #e4f1f9 0%,#d5e7f3 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top, #e4f1f9 0%,#d5e7f3 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top, #e4f1f9 0%,#d5e7f3 100%); /* IE10+ */
	background: linear-gradient(top, #e4f1f9 0%,#d5e7f3 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#e4f1f9', endColorstr='#d5e7f3',GradientType=0 ); /* IE6-9 */
	color:#7da2aa;
	cursor: pointer;
}

.lighter, .light, .dark {
	width: 95%;
	height: 50px;
	padding-top: 20px;
	padding-bottom: 10px;
}

.light{
	background: url('./images/light_grey.jpg');
}
.light input[type=text]{
	border:1px solid #acb1b7;
	background-color:#fcfcfc;
}

.product-info-img-s{
	padding:20px 10px;
	
	}
	
.checkout-div{
	padding:10px 20px;
	}
	
.btn-checkout {
  display: inline-block;
  padding: 6px 12px;
  width:100%;
  margin-bottom: 0;
  font-size: 18px;
  font-weight: normal;
  line-height: 1.42857143;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  -ms-touch-action: manipulation;
      touch-action: manipulation;
  cursor: pointer;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  background-image: none;
  border: 1px solid rgba(42,128,119,1.00);

}

.btn-checkout:active{
  background-image: none;
  outline: 0;
	}
	
.btn-checkout:hover{
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
	}
	
.btn-checkout:focus{
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, .125);
	}
	
	<!-- 2016-07-14-15-18 sing-in --!>
	
.sign-in-container{
	
	}
	
.sign-in-box{
	min-height:150px;
	text-align:center;
	margin:5% auto;
	max-width:500px;
	border:1px solid rgba(42,128,119,1.00);
	}
	
h2{
	color:rgba(186,152,104,1.00);
	font-size:30px;
	padding-bottom:10px;
}

.controls{
	padding:15px 8%;
	}
	
.line-input{
	border:none;
	color:#333;
	background:transparent;
	border-bottom: 1px solid rgba(42,128,119,1.00);
	padding:5px 2px 0px 2px;
	width:80%;
	}
.btn-sign-in{
	width:80%;
	float:none;
	padding:8px 2px 8px 2px;
	font-size:18px;


	}
	
.links-container{
	padding-top:20px;
	padding-bottom:20px;
	
	}
	
	<!-- 2016-07-14-15-18 sing-in --!>
	
.sign-in-container{
	
	}
	
.sign-in-box{
	min-height:150px;
	text-align:center;
	margin:5% auto;
	max-width:500px;
	border:1px solid rgba(42,128,119,1.00);
	}
	
h2{
	color:#5ab3ab;
	font-size:30px;
	padding-bottom:10px;
}

.controls{
	padding:15px 30px;
	}
	
.line-input{
	border:none;
	color:#333;
	background:transparent;
	border-bottom: 1px solid rgba(42,128,119,1.00);
	padding:5px 2px 0px 2px;
	width:80%;
	}
.btn-sign-in{
	width:80%;
	float:none;
	padding:8px 2px 8px 2px;
	font-size:18px;


	}
	
.links-container{
	padding-top:20px;
	padding-bottom:20px;
	
	}
	
<!-- 2016-07-14-15-18 sing-in --!>

<!--2016-07-15-15-02 page-info -->

.page-info-img-main{
	padding:auto 15px;
	border-left:auto;
	border-right:auto;
	
}

.page-info-img-auxiliary{
	padding-top:15px;
	padding-left:10px;
	padding-right:10px;
	
}

.page-info-text{
	padding:15px 15px;
	padding-bottom:25px;
	border-bottom:1px solid rgba(186,152,104,1.00)
}

.page-info-text h2{
	font-size:40px;
	 
}


.o-price{
	padding-top:10px;
	font-size:30px;
	text-decoration: line-through;
	color:#909090;

}

.p-price{
	padding-top:10px;
	font-size:25px;
	color:rgba(42,128,119,1.00);
}

.buy-control{
	padding-top:15px
}

.form-control-quantity{
	height:39px;
	
	}
	
.addtothecart{
	padding-top:20px;
}

lightbox-title, h4{
	text-align: center;	
	}
	
.lightbox-title{
	padding:5px  5px;
	height:50px
	
	}
	
.back-img{
	height:35px;

	}
	
.next-img{
	height:35px;
	float:right;
	}	
	
<!-- 2016-0718-->

.left-list ui li{
	font-size:18px;
	
}
<!-- mouse over Sidebar -->

@import url(//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css);
}
@import url(http://fonts.googleapis.com/css?family=Titillium+Web:300);
.fa-2x {
font-size: 2em;
}
.fa {
position: relative;
display: table-cell;
width: 40px;
height: 36px;
text-align: center;
vertical-align: middle;
font-size:20px;
}


.main-menu:hover,nav.main-menu.expanded {
width:160px;
overflow:visible;
}

.main-menu {
background: rgba(61,215,210,0.80);
border-left:1px solid rgba(108,177,170,1.00);
position:absolute;
top:0;
bottom:0;
height:100%;
right:0;
width:40px;
overflow:hidden;
-webkit-transition:width .05s linear;
transition:width .05s linear;
-webkit-transform:translateZ(0) scale(1,1);
z-index:1000;
}

.main-menu>ul {
margin:7px 0;
}

.main-menu li {
position:relative;
display:block;
width:250px;
padding:10px 0px;
}

.main-menu li>a {
position:relative;
display:table;
border-collapse:collapse;
border-spacing:0;
color:#999;
 font-family: arial;
font-size: 14px;
text-decoration:none;
-webkit-transform:translateZ(0) scale(1,1);
-webkit-transition:all .1s linear;
transition:all .1s linear;
  
}

.main-menu .nav-icon {
position:relative;
display:table-cell;
width:60px;
height:36px;
text-align:center;
vertical-align:middle;
font-size:18px;
}

.main-menu .nav-text {
position:relative;
display:table-cell;
vertical-align:middle;
width:190px;
  font-family: 'Times New Roman ltalic';
  color:rgb(10, 47, 43);
}

.main-menu>ul.logout {
position:absolute;
left:0;
bottom:0;
}

.no-touch .scrollable.hover {
overflow-y:hidden;
}

.no-touch .scrollable.hover:hover {
overflow-y:auto;
overflow:visible;
}

a:hover,a:focus {
text-decoration:none;
}

nav {
-webkit-user-select:none;
-moz-user-select:none;
-ms-user-select:none;
-o-user-select:none;
user-select:none;
}

nav ul,nav li {
outline:0;
margin:0;
padding:0;
}
.main-menu li:hover>a,nav.main-menu li.active>a,.dropdown-menu>li>a:hover,.dropdown-menu>li>a:focus,.dropdown-menu>.active>a,.dropdown-menu>.active>a:hover,.dropdown-menu>.active>a:focus,.no-touch .dashboard-page nav.dashboard-menu ul li:hover a,.dashboard-page nav.dashboard-menu ul li.active a {
color:#fff;
background-color:rgba(255,255,255,0.51);
}

.area {
float: left;
background: #e2e2e2;
width: 100%;
height: 100%;
}
@font-face {
  font-family: 'Times New Roman ltalic';
  font-style: normal;
  font-weight: 300;
}

<!-- End mouse over Sidebar -->

.img-padding{
	padding:2px 2px;
	
}
.sidemenu{
	display:table-cell;
	vertical-align: middle;
	padding-top:35vh;
	
	}
	
.sidemenu2{
	display:table-cell;
	vertical-align: middle;
	
	}
.sidemenu3{
	display:table-cell;
	vertical-align: middle;
	padding-top:80vh;
	
	}

	

	
	
.p-to-e-img:hover{
	-moz-box-shadow: 0 0 10px #4E4E4E; 
	-webkit-box-shadow: 0 0 10px #4E4E4E; 
	box-shadow: 0 0 10px #4E4E4E; 
	opacity: 0.5;
	}
	
.p-t-b{
	width:30vw
	}

.p-img-xs{
	padding:15px 15px;
	width:100%;
	}
	

.p-to-e-img-xs:hover{
	-moz-box-shadow: 0 0 10px #4E4E4E; 
	-webkit-box-shadow: 0 0 10px #4E4E4E; 
	box-shadow: 0 0 10px #4E4E4E; 
	opacity: 0.5;
	}
	
.logo-h:hover{
	-moz-box-shadow: 0 0 10px #B7B7B7; 
	-webkit-box-shadow: 0 0 10px #B7B7B7; 
	box-shadow: 0 0 10px #B7B7B7; 
	border-radius: 25px;

	}
	
@media (min-width: 200px) {
.img-hidden{
	display:none
		
}
.text-xs{
	text-align:left
	}	
.text-xs p{
	width:70% !important;
}
.p-to-e-img-xs{
	width:100%

}
.bottom-h1{
	position:fixed;
	bottom:28px;
	width:100vw;
	margin:0 autol;
	z-index:9;
	font-size:16px;
	}

}

@media (min-width: 560px) {
.img-hidden{
	display: inline
		
}
.text-xs{
	text-align: center;	
}
.text-xs p{
	width:50% !important;
}
.p-to-e-img-xs{
	width:74%

}
.bottom-h1{
	position:fixed;
	bottom:28px;
	width:100vw;
	margin:0 autol;
	z-index:9;
	font-size:24px;
	}


}

.bg-img-ch{}

#btn{background:red;}
#btn:hover{background:blue;}

.media-img{
	height:500px;
	margin-left:20px;
	margin-right:50px;
	-webkit-overflow-scrolling: touch;
	
	}
	
.media-img > * {
    -webkit-transform: translate3d(0,0,0);
}
