/* Clearfix */
.clearfix:before,
.clearfix:after {
    content: " ";
    display: table;
}
.clearfix:after {
    clear: both;
}
.clearfix {
    *zoom: 1;
}

/* Basic Styles */
body {
	background-color: #ece8e5;
}
.clearfix {
	height: 40px;
	width: 100%;
	background:rgba(61,215,210,0.20);
	font-size: 11pt;
	font-family: 'PT Sans', Arial, sans-serif;
	font-weight: bold;
	position: relative;
	border-bottom: 1px solid rgba(108,177,170,1.00);
}
.clearfix ul {
	padding: 0;
	margin: 0 auto;
	width: 600px;
	height: 40px;
}
.clearfix li {
	display: inline;
	float: left;
}
.clearfix a {
	color: #fff;
	display: inline-block;
	width: 100px;
	text-align: center;
	text-decoration: none;
	line-height: 40px;
}
.clearfix li a {
	border-right:rgba(108,177,170,1.00);
	box-sizing:border-box;
	-moz-box-sizing:border-box;
	-webkit-box-sizing:border-box;
}
.clearfix li:last-child a {
	border-right: 0;
}
.clearfix a:hover, .clearfix a:active {
	background-color: #C0F8FF;
}
.clearfix a#pull {
	display: none;
}

/*Styles for screen 600px and lower*/
@media screen and (max-width: 600px) {
	.clearfix { 
  		height: auto;
  	}
  	.clearfix ul {
  		width: 100%;
  		display: block;
  		height: auto;
  	}
  	.clearfix li {
  		width: 50%;
  		float: left;
  		position: relative;
  	}
  	.clearfix li a {
		border-bottom:#C0F8FF;
		border-right:#C0F8FF;
	}
  	.clearfix a {
	  	text-align: left;
	  	width: 100%;
	  	text-indent: 25px;
  	}
}

/*Styles for screen 515px and lower*/
@media only screen and (max-width : 480px) {
	.clearfix {
		border-bottom: 0;
	}
	.clearfix ul {
		display: none;
		height: auto;
	}
	.clearfix a#pull {
		display: block;
		background-color:rgba(61,215,210,0.20);
		width: 100%;
		position: relative;
	}
	.clearfix a#pull:after {
		content:"";
		background: url('nav-icon.png') no-repeat;
		width: 30px;
		height: 30px;
		display: inline-block;
		position: absolute;
		right: 15px;
		top: 10px;
	}
}

/*Smartphone*/
@media only screen and (max-width : 320px) {
	.clearfix li {
		display: block;
		float: none;
		width: 100%;
	}
	.clearfix li a {
		border-bottom: 1px solid #C0F8FF;
	}
}